==> kdesdk_4.6.5.orig.tar.bz2: kdesdk-4.6.5/okteta/mobile/program/mainwindow.h <==
/*
    This file is part of the Okteta Mobile program, part of the KDE project.

    Copyright 2006-2008,2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License or (at your option) version 3 or any later version
    accepted by the membership of KDE e.V. (or its successor approved
    by the membership of KDE e.V.), which shall act as a proxy 
    defined in Section 14 of version 3 of the license.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef OKTETAMAINWINDOW_H
#define OKTETAMAINWINDOW_H

// Kasten gui
#include <mobileshellwindow.h>


namespace Kasten
{

class OktetaProgram;


class OktetaMainWindow : public MobileShellWindow
{
   Q_OBJECT

  public:
    explicit OktetaMainWindow( OktetaProgram *program );
    virtual ~OktetaMainWindow();

  protected: // KMainWindow API
    virtual void saveProperties( KConfigGroup &configGroup );
    virtual void readProperties( const KConfigGroup &configGroup );

  protected:
    void setupControllers();

  protected:
    OktetaProgram* mProgram;
};

}

#endif

==> kdesdk-4.7.1.tar.bz2: kdesdk-4.7.1/okteta/mobile/program/mainwindow.h <==
/*
    This file is part of the Okteta Mobile program, made within the KDE community.

    Copyright 2006-2008,2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License or (at your option) version 3 or any later version
    accepted by the membership of KDE e.V. (or its successor approved
    by the membership of KDE e.V.), which shall act as a proxy 
    defined in Section 14 of version 3 of the license.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef OKTETAMAINWINDOW_H
#define OKTETAMAINWINDOW_H

// Kasten gui
#include <mobileshellwindow.h>


namespace Kasten
{

class OktetaProgram;


class OktetaMainWindow : public MobileShellWindow
{
   Q_OBJECT

  public:
    explicit OktetaMainWindow( OktetaProgram *program );
    virtual ~OktetaMainWindow();

  protected: // KMainWindow API
    virtual void saveProperties( KConfigGroup &configGroup );
    virtual void readProperties( const KConfigGroup &configGroup );

  protected:
    void setupControllers();

  protected:
    OktetaProgram* mProgram;
};

}

#endif
